/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@gnome.org>
 *
 *  Copyright 2002 - 2006 Iain Holmes
 *
 *  This file is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public
 *  License as published by the Free Software Foundation;
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MARLIN_JACK_H__
#define __MARLIN_JACK_H__

#include <glib-object.h>

#include <jack/jack.h>

G_BEGIN_DECLS

#define MARLIN_JACK_TYPE (marlin_jack_get_type ())
#define MARLIN_JACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MARLIN_JACK_TYPE, MarlinJack))
#define MARLIN_JACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MARLIN_JACK_TYPE, MarlinJackClass))

#define MARLIN_JACK_ERROR marlin_jack_error_quark ()

typedef enum {
	MARLIN_JACK_ERROR_NO_SERVER, /* Server did not exist */
	MARLIN_JACK_ERROR_NO_SAMPLE, /* No sample to playback */
} MarlinJackError;

typedef struct _MarlinJack MarlinJack;
typedef struct _MarlinJackPrivate MarlinJackPrivate;
typedef struct _MarlinJackClass MarlinJackClass;

struct _MarlinJack {
	GObject parent;

	MarlinJackPrivate *priv;
};

struct _MarlinJackClass {
	GObjectClass parent_class;

	void (*eos) (MarlinJack *jack);
	void (*status_changed) (MarlinJack *jack,
				int status);
	void (*position_changed) (MarlinJack *jack,
				  guint64 position);
};

GType marlin_jack_get_type (void);
MarlinJack *marlin_jack_new (const char *client_name,
			     const char *server_name,
			     GError **error);

gboolean marlin_jack_start_playback (MarlinJack *jack,
				     guint64     start,
				     guint64     finish,
				     gboolean    repeating,
				     GError    **error);
gboolean marlin_jack_start_recording (MarlinJack *jack,
				      GError    **error);
void marlin_jack_stop (MarlinJack *jack);
void marlin_jack_pause (MarlinJack *jack);
void marlin_jack_continue (MarlinJack *jack);

G_END_DECLS

#endif
