/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@gnome.org>
 *
 *  Copyright 2003-2007 Iain Holmes
 *
 *  This file is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU Library General Public
 *  License as published by the Free Software Foundation;
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib.h>

#include <marlin/marlin-list.h>

MarlinList *
marlin_list_new (void)
{
	return g_new0 (MarlinList, 1);
}

void
marlin_list_free (MarlinList *list)
{
	MarlinListNode *node;

	node = list->first;
	while (node) {
		MarlinListNode *old = node;

		node = node->next;

		/* This assumes that nothing is allocated in the 
		   struct derived from MarlinListNode */
		g_free (old);
	}
	g_free (list);
}

void
marlin_list_append (MarlinList *list,
		    MarlinListNode *a)
{
	if (list->last) {
		a->previous = list->last;
		a->next = NULL;
		list->last->next = a;
		list->last = a;
	} else {
		list->first = a;
		list->last = a;
	}
}

MarlinListNode *
marlin_list_node_next (MarlinListNode *a)
{
	return a->next;
}

MarlinListNode *
marlin_list_node_previous (MarlinListNode *a)
{
	return a->previous;
}
